clear all, close all, clc

%% Chargement du modele initial
load modelClampedBeam
H         = sysFEM(end,1); % On ne considre que la dernire sortie
n         = length(H.A); % Dimension du modle initial
[A,B,C,D] = ssdata(H);
In        = eye(n);

%% Choix des points et directions d'interpolation
la = 2*pi*148.5*[1 -1]*i;
mu = la; % pour avoir interpolation Hermitienne
%mu = 2*pi*1.723*[1 -1]*i; % pour avoir interpolation
r  = [1 -1]*i;
l  = [1 -1]*i;

%% Gnration de Vk et Wq et projection
Vk = [(la(1)*In-A)\(B*r(1))          (la(2)*In-A)\(B*r(2))];
Wq = [((l(1)'*C)*((mu(1)*In-A)\In))' ((l(2)'*C)*((mu(2)*In-A)\In))'];
Wq = Wq*((Wq'*Vk)\eye(2))';
Ar = Wq'*A*Vk;
Br = Wq'*B;
Cr = C*Vk;
Hr = ss(Ar,Br,Cr,D);

%% Vrification des conditions d'interpolation
abs((freqresp(H,la(1))-freqresp(Hr,la(1)))*r(:,1))  / abs(freqresp(H,la(1))*r(:,1))
abs((freqresp(H,la(2))-freqresp(Hr,la(2)))*r(:,2))  / abs(freqresp(H,la(2))*r(:,2))
abs(l(:,1)'*(freqresp(H,mu(1))-freqresp(Hr,mu(1)))) / abs(l(:,1)'*freqresp(H,mu(1)))
abs(l(:,2)'*(freqresp(H,mu(2))-freqresp(Hr,mu(2)))) / abs(l(:,2)'*freqresp(H,mu(2)))
abs(l(:,1)'*(C*(la(1)*In-A)^(-2)*B - Cr*(la(1)*eye(2)-Ar)^(-2)*Br)*r(:,1)) / abs(l(:,1)'*(C*(la(1)*In-A)^(-2)*B)*r(:,1))
abs(l(:,1)'*(C*(mu(1)*In-A)^(-2)*B - Cr*(mu(1)*eye(2)-Ar)^(-2)*Br)*r(:,1)) / abs(l(:,1)'*(C*(mu(1)*In-A)^(-2)*B)*r(:,1))

%% Rsultats
wmin = 1;
wmax = 1e4;
w    = logspace(log10(wmin),log10(wmax),300);
Mh   = bode(H,w);
Mhr  = bode(Hr, w);
Mhr_points = bode(Hr, [norm(la(1)) norm(mu(1))]);
semilogx(w/(2*pi), 20*log(abs(squeeze(Mh))),'b');
hold on
semilogx(w/(2*pi), 20*log(abs(squeeze(Mhr))),'r--');
semilogx([norm(la(1)) norm(mu(1))]/(2*pi), 20*log(abs(squeeze(Mhr_points))),'k.');
set(gca(),'fontsize',20);
set(gca(),'xLim',[wmin, wmax]/(2*pi));
ll = legend('$H_{900}$','$\hat{H}$','Points d''interpolation');
set(ll,'interpreter','latex','fontsize',26,'Location','SouthWest');
xlabel('Fr\''equence (Hz)','interpreter','latex','fontsize',26);
ylabel('Gain (dB)','interpreter','latex','fontsize',26);
grid on

